ps.zope.i18nfield
*****************

Introduction
============

This package provides a `zope.schema`_ based field which allows multiple translations within the field.
It uses a custom dictionary class for the storage.
There is also a widget available for the `z3c.form`_ library.

.. _`z3c.form`: https://pypi.python.org/pypi/z3c.form
.. _`zope.schema`: https://pypi.python.org/pypi/zope.schema


Mostly Harmless
---------------

.. image:: https://travis-ci.org/propertyshelf/ps.zope.i18nfield.svg?branch=master
   :target: https://travis-ci.org/propertyshelf/ps.zope.i18nfield
